==> lib_common_fx-0.0.17.tar.gz: lib/ui/bottom_item_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:lib_common_fx/lib_common_fx.dart';
import 'package:lib_common_fx/utils/image_utils.dart';

typedef BottomItemCallBack<T> = Widget Function(int index);

class BottomItemDialog extends StatefulWidget {
  final List dataList;
  final String title;
  final int? selectId;
  final Function? tapFunction;
  final ScrollPhysics? physics;
  final double maxHeight;
  final BottomItemCallBack callBack;

  const BottomItemDialog({
    Key? key,
    required this.dataList,
    required this.title,
    this.selectId,
    this.tapFunction,
    this.physics,
    required this.maxHeight,
    required this.callBack,
  }) : super(key: key);

  @override
  _BottomItemDialogState createState() => _BottomItemDialogState();
}

class _BottomItemDialogState extends State<BottomItemDialog> {
  BaseEntity? selectEntity;
  late int sId = 0;
  List _dataList = [];

  @override
  void initState() {
    super.initState();
    EventBus().on("refreshDataList", (arg) {
      setState(() {
        _dataList = widget.dataList;
      });
    });
    _dataList = widget.dataList;
    if (widget.selectId != null) {
      sId = widget.selectId ?? 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Dialog(
        alignment: Alignment.bottomCenter,
        //设置align居下
        insetPadding: const EdgeInsets.only(left: 0, right: 0),
        //去掉默认边距
        backgroundColor: FXColor.main_white,
        shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.only(topRight: Radius.circular(10), topLeft: Radius.circular(10))),
        child: Container(
            // height: 347,
            constraints: BoxConstraints(minHeight: 302, maxHeight: widget.maxHeight),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.end,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SizedBox(
                      width: double.infinity,
                      height: 46,
                      child: Stack(alignment: Alignment.bottomCenter, children: [
                        FXText(widget.title,
                            style:
                                FXText.content.apply(fontWeightDelta: 2, color: FXColor.main_black1, fontSizeDelta: 2)),
                        Positioned(
                            top: 0,
                            right: 0,
                            // right: 46,
                            child: GestureDetector(
                                onTap: () {
                                  Navigator.pop(context);
                                },
                                child: Container(
                                    height: 16,
                                    margin: const EdgeInsets.only(right: 12, top: 12),
                                    child: ImageUtil.assetImage('images/close.png',
                                      height: 16,
                                    ))))
                      ])),
                  const SizedBox(
                    height: 8,
                  ),
                  Expanded(
                      child: ListView.builder(
                          physics: widget.physics ?? const BouncingScrollPhysics(),
                          itemCount: _dataList.length,
                          itemBuilder: (BuildContext context, int index) {
                            BaseEntity entity = _dataList[index];
                            if (entity.getId() == sId) {
                              selectEntity = entity;
                            }
                            Widget itemWidget = widget.callBack(index);
                            return _buildItem(entity, itemWidget);
                          })),
                  // _buidItems(),
                  GestureDetector(
                      onTap: () => _confirm(),
                      child: Container(
                        height: 48,
                        width: double.infinity,
                        alignment: Alignment.center,
                        margin: const EdgeInsets.only(left: 12, right: 12, top: 16, bottom: 16),
                        decoration: const BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(10)), color: FXColor.main_blue),
                        child:
                            CenterText("确认", style: FXText.content.apply(fontSizeDelta: 2, color: FXColor.main_white)),
                      ))
                ])));
  }

  // Widget _buidItems(){
  //   List<Widget> tiles = [];
  //   for(DialogEntity entity in widget.dataList){
  //     tiles.add(_buildItem(entity));
  //   }
  //   Widget content = Column(children: tiles,);
  //   return content;
  // }
  Widget _buildItem(BaseEntity entity, Widget itemWidget) {
    return GestureDetector(
      onTap: () => _select(entity),
      child: Container(
        // height: 63,
        width: double.infinity,
        margin: const EdgeInsets.only(left: 27, right: 27, top: 8),
        // color: FXColor.main_black6,
        decoration: BoxDecoration(
            borderRadius: const BorderRadius.all(Radius.circular(10)),
            border: Border.all(width: 0.5, color: (entity.getId() == sId) ? FXColor.main_blue : FXColor.main_black6),
            color: (entity.getId() == sId) ? FXColor.main_blue.withOpacity(0.1) : FXColor.main_black6),
        child: itemWidget,
      ),
    );
  }

  void _confirm() {
    Navigator.pop(context, selectEntity);
  }

  void _select(BaseEntity entity) {
    setState(() {
      sId = entity.getId();
    });
    selectEntity = entity;
  }

  @override
  void dispose() {
    EventBus().off("refreshDataList");
    super.dispose();
  }
}

==> lib_common_fx-0.0.41.tar.gz: lib/ui/bottom_item_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:lib_common_fx/lib_common_fx.dart';
import 'package:lib_common_fx/utils/image_utils.dart';

typedef BottomItemCallBack<T> = Widget Function(int index);

class BottomItemDialog extends StatefulWidget {
  final List dataList;
  final String title;
  final int? selectId;
  final Function? tapFunction;
  final ScrollPhysics? physics;
  final double maxHeight;
  final BottomItemCallBack callBack;
  final bool hasConfirm;
  final Widget? customWidget;

  const BottomItemDialog({
    Key? key,
    required this.dataList,
    required this.title,
    this.selectId,
    this.tapFunction,
    this.physics,
    required this.maxHeight,
    required this.callBack, this.hasConfirm = true, this.customWidget,
  }) : super(key: key);

  @override
  _BottomItemDialogState createState() => _BottomItemDialogState();
}

class _BottomItemDialogState extends State<BottomItemDialog> {
  BaseEntity? selectEntity;
  late int sId = 0;
  // List _dataList = [];

  @override
  void initState() {
    super.initState();
    // EventBus().on("refreshDataList", (arg) {
    //   setState(() {
    //     _dataList = widget.dataList;
    //   });
    // });
    // _dataList = widget.dataList;
    if (widget.selectId != null) {
      sId = widget.selectId ?? 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Dialog(
        alignment: Alignment.bottomCenter,
        //设置align居下
        insetPadding: const EdgeInsets.only(left: 0, right: 0),
        //去掉默认边距
        backgroundColor: FXColor.main_white,
        shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.only(topRight: Radius.circular(10), topLeft: Radius.circular(10))),
        child: Container(
            // height: 347,
            constraints: BoxConstraints(minHeight: 200, maxHeight: widget.maxHeight),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.end,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SizedBox(
                      width: double.infinity,
                      height: 46,
                      child: Stack(alignment: Alignment.bottomCenter, children: [
                        FXText(widget.title,
                            style:
                                FXText.content.apply(fontWeightDelta: 2, color: FXColor.main_black1, fontSizeDelta: 2)),
                        Positioned(
                            top: 0,
                            right: 0,
                            // right: 46,
                            child: GestureDetector(
                                onTap: () {
                                  Navigator.pop(context);
                                },
                                child: Container(
                                    height: 16,
                                    margin: const EdgeInsets.only(right: 12, top: 12),
                                    child: ImageUtil.assetImage('images/close.png',
                                      height: 16,
                                    ))))
                      ])),
                  const SizedBox(
                    height: 8,
                  ),
                  Expanded(
                      child: ListView.builder(
                          physics: widget.physics ?? const BouncingScrollPhysics(),
                          itemCount: widget.dataList.length,
                          itemBuilder: (BuildContext context, int index) {
                            BaseEntity entity = widget.dataList[index];
                            if (entity.getId() == sId) {
                              selectEntity = entity;
                            }
                            Widget itemWidget = widget.callBack(index);
                            return _buildItem(entity, itemWidget);
                          })),
                  // _buidItems(),
                  if(widget.customWidget != null) widget.customWidget!,
                  if(widget.hasConfirm) GestureDetector(
                      onTap: () => _confirm(),
                      child: Container(
                        height: 48,
                        width: double.infinity,
                        alignment: Alignment.center,
                        margin: const EdgeInsets.only(left: 12, right: 12, top: 16, bottom: 16),
                        decoration: const BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(10)), color: FXColor.main_blue),
                        child:
                            CenterText("确认", style: FXText.content.apply(fontSizeDelta: 2, color: FXColor.main_white)),
                      )),
                  if(!widget.hasConfirm) const SizedBox(height: 16,),
                ])));
  }

  // Widget _buidItems(){
  //   List<Widget> tiles = [];
  //   for(DialogEntity entity in widget.dataList){
  //     tiles.add(_buildItem(entity));
  //   }
  //   Widget content = Column(children: tiles,);
  //   return content;
  // }
  Widget _buildItem(BaseEntity entity, Widget itemWidget) {
    return GestureDetector(
      onTap: () => _select(entity),
      child: Container(
        // height: 63,
        width: double.infinity,
        margin: const EdgeInsets.only(left: 27, right: 27, top: 8),
        // color: FXColor.main_black6,
        decoration: BoxDecoration(
            borderRadius: const BorderRadius.all(Radius.circular(10)),
            border: Border.all(width: 0.5, color: (entity.getId() == sId) ? FXColor.main_blue : FXColor.main_black6),
            color: (entity.getId() == sId) ? FXColor.main_blue.withOpacity(0.1) : FXColor.main_black6),
        child: itemWidget,
      ),
    );
  }

  void _confirm() {
    Navigator.pop(context, selectEntity);
  }

  void _select(BaseEntity entity) {
    setState(() {
      sId = entity.getId();
    });
    selectEntity = entity;
    if(!widget.hasConfirm) {
      _confirm();
    }
  }

  @override
  void dispose() {
    EventBus().off("refreshDataList");
    super.dispose();
  }
}
